@@ -73,7 +73,8 @@ def validate_compatible_path(path):
                 )
             )
     except:
-        print("Warning:无法计算相对位置，盘符不一致")
+        #print("Warning:无法计算相对位置，盘符不一致")
+        pass
     
 
     
@@ -104,6 +105,7 @@ class ResourceLoader:
             self.absolute_path = False
 
     def _root(self):
+        #print('a',os.path.join(root, self.subpath))
         return os.path.join(root, self.subpath)
 
     @staticmethod
@@ -119,7 +121,7 @@ class ResourceLoader:
         if not self.have_root:
             self.validate_root(name)
         p = os.path.join(self._root(), name)
-        #print(p)
+        #print(self._root())
         if not os.path.isfile(p):
             for ext in self.EXTNS:
                 p = os.path.join(self._root(), name + '.' + ext)
@@ -148,6 +150,7 @@ class ResourceLoader:
 
     def __getattr__(self, name):
         p = os.path.join(self._root(), name)
+        #print(self._root())
         if os.path.isdir(p):
             resource = self.__class__(os.path.join(self.subpath, name))
         else:
